@@ -21,11 +21,11 @@ Date::Cmp - Compare two dates with approximate parsing support
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -138,6 +138,19 @@ sub datecmp
 
 	return 0 if($left eq $right);
 
+	if((!ref($left)) && (!ref($right)) && ($left =~ /\d{3,4}/) && ($right =~ /\d{3,4}/) && ($left !~ /^bet/i) && ($right !~ /^bet/i)) {
+		if($left =~ /(\d{4})/) {
+			my $lyear = $1;
+			if($right =~ /(\d{4})/) {
+				my $ryear = $1;
+
+				if($lyear != $ryear) {
+					return $lyear <=> $ryear;
+				}
+			}
+		}
+	}
+
 	if((!ref($left)) && (!ref($right)) && ($left =~ /(\d{3,4})$/) && ($left !~ /^bet/i) && ($right !~ /^bet/i)) {
 		# Simple year test for fast comparison
 		my $yol = $1;
